# tap-appsflyer

This is a [Singer](https://singer.io) tap that produces JSON-formatted data
following the [Singer
spec](https://github.com/singer-io/getting-started/blob/master/docs/SPEC.md).

This tap:

- Pulls raw data from the [appsflyer API](https://dev.appsflyer.com/hc/reference/overview-5).
- Extracts the following resources:
    - [Installs](https://dev.appsflyer.com/hc/reference/get_app-id-installs-report-v5)

    - [Organic Installs](https://dev.appsflyer.com/hc/reference/get_app-id-organic-installs-report-v5)

    - [In App Events](https://dev.appsflyer.com/hc/reference/get_app-id-in-app-events-report-v5)

- Outputs the schema for each resource
- Incrementally pulls data based on the input state


## Streams


**[installs](https://dev.appsflyer.com/hc/reference/get_app-id-installs-report-v5)**
- Primary keys: ["event_time", "event_name", "appsflyer_id"]
- Replication strategy: INCREMENTAL

**[organic_installs](https://dev.appsflyer.com/hc/reference/get_app-id-organic-installs-report-v5)**
- Primary keys: ["event_time", "event_name", "appsflyer_id"]
- Replication strategy: INCREMENTAL

**[in_app_events](https://dev.appsflyer.com/hc/reference/get_app-id-in-app-events-report-v5)**
- Primary keys: ["event_time", "event_name", "appsflyer_id"]
- Replication strategy: INCREMENTAL



## Authentication

## Quick Start

1. Install

    Clone this repository, and then install using setup.py. We recommend using a virtualenv:

    ```bash
    > virtualenv -p python3 venv
    > source venv/bin/activate
    > python setup.py install
    OR
    > cd .../tap-appsflyer
    > pip install -e .
    ```
2. Dependent libraries. The following dependent libraries were installed.
    ```bash
    > pip install singer-python
    > pip install target-stitch
    > pip install target-json

    ```
    - [singer-tools](https://github.com/singer-io/singer-tools)
    - [target-stitch](https://github.com/singer-io/target-stitch)

3. Create your tap's `config.json` file.  The tap config file for this tap should include these entries:
   - `start_date` (optional): the default value is (now - 30 days) to use if no bookmark/start_date exists for an endpoint (rfc3339 date string)
   - `user_agent` (string, optional): Process and email for API logging purposes. Example: `tap-appsflyer <api_user_email@your_company.com>`
   - `app_id`: Application ID of the respective Appsflyer app
   - `api_token`: API token of the respective Appsflyer app

    ```json
    {
        "start_date": "2019-01-01T00:00:00Z",
        "user_agent": "tap-appsflyer <api_user_email@your_company.com>",
        "app_id": "abc1e2swewe",
        "api_token": "askawqewdqwer123445666"
        ...
    }
    ```

    Optionally, also create a `state.json` file. `currently_syncing` is an optional attribute used for identifying the last object to be synced in case the job is interrupted mid-stream. The next run would begin where the last job left off.

    ```json
    {
        "currently_syncing": "in_app_events",
        "bookmarks": {
            "installs": "2019-09-27T22:34:39.000000Z"
        }
    }
    ```

4. Run the Tap in Discovery Mode
    This creates a catalog.json for selecting objects/fields to integrate:
    ```bash
    tap-appsflyer --config config.json --discover > catalog.json
    ```
   See the Singer docs on discovery mode
   [here](https://github.com/singer-io/getting-started/blob/master/docs/DISCOVERY_MODE.md)

5. Run the Tap in Sync Mode (with catalog) and [write out to state file](https://github.com/singer-io/getting-started/blob/master/docs/RUNNING_AND_DEVELOPING.md)

    For Sync mode:
    ```bash
    > tap-appsflyer --config tap_config.json --catalog catalog.json > state.json
    > tail -1 state.json > state.json.tmp && mv state.json.tmp state.json
    ```
    To load to json files to verify outputs:
    ```bash
    > tap-appsflyer --config tap_config.json --catalog catalog.json | target-json > state.json
    > tail -1 state.json > state.json.tmp && mv state.json.tmp state.json
    ```
    To pseudo-load to [Stitch Import API](https://github.com/singer-io/target-stitch) with dry run:
    ```bash
    > tap-appsflyer --config tap_config.json --catalog catalog.json | target-stitch --config target_config.json --dry-run > state.json
    > tail -1 state.json > state.json.tmp && mv state.json.tmp state.json
    ```

6. Test the Tap

    While developing the appsflyer tap, the following utilities were run in accordance with Singer.io best practices:
    Pylint to improve [code quality](https://github.com/singer-io/getting-started/blob/master/docs/BEST_PRACTICES.md)
    ```bash
    > pylint tap_appsflyer -d missing-docstring -d logging-format-interpolation -d too-many-locals -d too-many-arguments
    ```
    Pylint test resulted in the following score:
    ```bash
    Your code has been rated at 9.67/10
    ```

    To [check the tap](https://github.com/singer-io/singer-tools)
    ```bash
    > tap-appsflyer --config tap_config.json --catalog catalog.json | singer-check-tap > state.json
    > tail -1 state.json > state.json.tmp && mv state.json.tmp state.json
    ```

    #### Unit Tests

    Unit tests may be run with the following.

    ```
    python -m pytest --verbose
    ```

    Note, you may need to install test dependencies.

    ```
    pip install -e .'[dev]'
    ```
---

Copyright &copy; 2017 Stitch
